@@ -5,14 +5,14 @@ use warnings;
 use bytes;
 require Exporter ;
 
-use IO::Compress::Base 2.092 ;
+use IO::Compress::Base 2.093 ;
 
-use IO::Compress::Base::Common  2.092 qw(createSelfTiedObject);
-use IO::Compress::Adapter::Lzip 2.092 ;
+use IO::Compress::Base::Common  2.093 qw(createSelfTiedObject);
+use IO::Compress::Adapter::Lzip 2.093 ;
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $LzipError);
 
-$VERSION = '2.092';
+$VERSION = '2.093';
 $LzipError = '';
 
 @ISA    = qw(IO::Compress::Base Exporter);
@@ -234,7 +234,7 @@ It can take one of the following forms:
 
 =item A filename
 
-If the <$input_filename_or_reference> parameter is a simple scalar, it is
+If the C<$input_filename_or_reference> parameter is a simple scalar, it is
 assumed to be a filename. This file will be opened for reading and the
 input data will be read from it.
 
