@@ -4,15 +4,15 @@ use strict ;
 use warnings;
 use bytes;
 
-use IO::Compress::Base::Common 2.092 qw(:Status createSelfTiedObject);
+use IO::Compress::Base::Common 2.093 qw(:Status createSelfTiedObject);
 
-use IO::Uncompress::Base 2.092 ;
-use IO::Uncompress::Adapter::UnLzip 2.092 ;
+use IO::Uncompress::Base 2.093 ;
+use IO::Uncompress::Adapter::UnLzip 2.093 ;
 
 require Exporter ;
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $UnLzipError);
 
-$VERSION = '2.092';
+$VERSION = '2.093';
 $UnLzipError = '';
 
 @ISA    = qw( IO::Uncompress::Base Exporter );
@@ -277,7 +277,7 @@ It can take one of the following forms:
 
 =item A filename
 
-If the <$input_filename_or_reference> parameter is a simple scalar, it is
+If the C<$input_filename_or_reference> parameter is a simple scalar, it is
 assumed to be a filename. This file will be opened for reading and the
 input data will be read from it.
 
